@@ -1,41 +1,42 @@
 /*
   SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "messagefactoryng.h"
 
-#include "settings/messagecomposersettings.h"
+#include "draftstatus/draftstatus.h"
 #include "messagefactoryforwardjob.h"
 #include "messagefactoryreplyjob.h"
-#include "MessageComposer/Util"
+#include "settings/messagecomposersettings.h"
+#include <MessageComposer/Util>
 
-#include <AkonadiCore/item.h>
-#ifndef QT_NO_CURSOR
-#include <Libkdepim/KCursorSaver>
-#endif
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
-#include <KIdentityManagement/kidentitymanagement/identity.h>
+#include <KCursorSaver>
+
+#include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
 
-#include <Akonadi/KMime/MessageStatus>
-#include <kmime/kmime_dateformatter.h>
-#include <KEmailAddress>
-#include <MessageCore/MailingList>
-#include <MessageCore/StringUtil>
 #include "helper/messagehelper.h"
-#include <KLocalizedString>
 #include "messagecomposer_debug.h"
 #include <KCharsets>
+#include <KEmailAddress>
+#include <KLocalizedString>
+#include <KMime/DateFormatter>
+#include <MessageCore/MailingList>
+#include <MessageCore/StringUtil>
+#include <MessageCore/Util>
 #include <QRegularExpression>
 #include <QTextCodec>
 
 using namespace MessageComposer;
 
-namespace KMime {
-namespace Types {
+namespace KMime
+{
+namespace Types
+{
 static bool operator==(const KMime::Types::Mailbox &left, const KMime::Types::Mailbox &right)
 {
     return left.addrSpec().asString() == right.addrSpec().asString();
@@ -72,14 +73,11 @@ MessageFactoryNG::MessageFactoryNG(const KMime::Message::Ptr &origMsg, Akonadi::
 {
 }
 
-MessageFactoryNG::~MessageFactoryNG()
-{
-}
+MessageFactoryNG::~MessageFactoryNG() = default;
 
 // Return the addresses to use when replying to the author of msg.
 // See <https://cr.yp.to/proto/replyto.html>.
-static KMime::Types::Mailbox::List authorMailboxes(
-    const KMime::Message::Ptr &msg, const KMime::Types::Mailbox::List &mailingLists)
+static KMime::Types::Mailbox::List authorMailboxes(const KMime::Message::Ptr &msg, const KMime::Types::Mailbox::List &mailingLists)
 {
     if (auto mrt = msg->headerByType("Mail-Reply-To")) {
         return KMime::Types::Mailbox::listFrom7BitString(mrt->as7BitString(false));
@@ -103,17 +101,13 @@ void MessageFactoryNG::slotCreateReplyDone(const KMime::Message::Ptr &msg, bool
 
     MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusReplied());
     if (mParentFolderId > 0) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Fcc");
+        auto header = new KMime::Headers::Generic("X-KMail-Fcc");
         header->fromUnicodeString(QString::number(mParentFolderId), "utf-8");
         msg->setHeader(header);
     }
 
-    if (auto hrd = mOrigMsg->headerByType("X-KMail-EncryptActionEnabled")) {
-        if (hrd->as7BitString(false).contains("true")) {
-            auto header = new KMime::Headers::Generic("X-KMail-EncryptActionEnabled");
-            header->fromUnicodeString(QStringLiteral("true"), "utf-8");
-            msg->setHeader(header);
-        }
+    if (DraftEncryptionState(mOrigMsg).encryptionState()) {
+        DraftEncryptionState(msg).setState(true);
     }
     msg->assemble();
 
@@ -138,10 +132,7 @@ void MessageFactoryNG::createReplyAsync()
     msg->contentType()->setCharset("utf-8");
 
     if (auto hdr = mOrigMsg->headerByType("List-Post")) {
-        static const QRegularExpression rx {
-            QStringLiteral("<\\s*mailto\\s*:([^@>]+@[^>]+)>"),
-            QRegularExpression::CaseInsensitiveOption
-        };
+        static const QRegularExpression rx{QStringLiteral("<\\s*mailto\\s*:([^@>]+@[^>]+)>"), QRegularExpression::CaseInsensitiveOption};
         const auto match = rx.match(hdr->asUnicodeString());
         if (match.hasMatch()) {
             KMime::Types::Mailbox mailbox;
@@ -151,8 +142,7 @@ void MessageFactoryNG::createReplyAsync()
     }
 
     switch (mReplyStrategy) {
-    case MessageComposer::ReplySmart:
-    {
+    case MessageComposer::ReplySmart: {
         if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             toList << KMime::Types::Mailbox::listFrom7BitString(hdr->as7BitString(false));
         } else if (!mMailingListAddresses.isEmpty()) {
@@ -167,8 +157,7 @@ void MessageFactoryNG::createReplyAsync()
             auto originalToList = mOrigMsg->to()->mailboxes();
 
             if (mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
-                && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
-                ) {
+                && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))) {
                 // Sender seems to be one of our own identities and recipient is not,
                 // so we assume that this is a reply to a "sent" mail where the user
                 // wants to add additional information for the recipient.
@@ -191,14 +180,13 @@ void MessageFactoryNG::createReplyAsync()
         }
         break;
     }
-    case MessageComposer::ReplyList:
-    {
+    case MessageComposer::ReplyList: {
         if (auto hdr = mOrigMsg->headerByType("Mail-Followup-To")) {
             KMime::Types::Mailbox mailbox;
             mailbox.from7BitString(hdr->as7BitString(false));
             toList << mailbox;
         } else if (!mMailingListAddresses.isEmpty()) {
-            toList << mMailingListAddresses[ 0 ];
+            toList << mMailingListAddresses[0];
         } else if (!replyToList.isEmpty()) {
             // assume a Reply-To header mangling mailing list
             toList = replyToList;
@@ -219,7 +207,7 @@ void MessageFactoryNG::createReplyAsync()
             if (!mMailingListAddresses.isEmpty()) {
                 toList = stripMyAddressesFromAddressList(mOrigMsg->to()->mailboxes(), mIdentityManager);
                 bool addMailingList = true;
-                for (const KMime::Types::Mailbox &m : qAsConst(mMailingListAddresses)) {
+                for (const KMime::Types::Mailbox &m : std::as_const(mMailingListAddresses)) {
                     if (toList.contains(m)) {
                         addMailingList = false;
                         break;
@@ -236,8 +224,7 @@ void MessageFactoryNG::createReplyAsync()
                 auto originalToList = mOrigMsg->to()->mailboxes();
 
                 if (mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalFromList))
-                    && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))
-                    ) {
+                    && !mIdentityManager->thatIsMe(KMime::Types::Mailbox::listToUnicodeString(originalToList))) {
                     // Sender seems to be one of our own identities and recipient is not,
                     // so we assume that this is a reply to a "sent" mail where the user
                     // wants to add additional information for the recipient.
@@ -249,7 +236,7 @@ void MessageFactoryNG::createReplyAsync()
                 }
             }
 
-            for (const KMime::Types::Mailbox &mailbox : qAsConst(ccList)) {
+            for (const KMime::Types::Mailbox &mailbox : std::as_const(ccList)) {
                 msg->cc()->addAddress(mailbox);
             }
         }
@@ -265,7 +252,7 @@ void MessageFactoryNG::createReplyAsync()
         Q_UNREACHABLE();
     }
 
-    for (const KMime::Types::Mailbox &mailbox : qAsConst(toList)) {
+    for (const KMime::Types::Mailbox &mailbox : std::as_const(toList)) {
         msg->to()->addAddress(mailbox);
     }
 
@@ -273,14 +260,14 @@ void MessageFactoryNG::createReplyAsync()
     if (!refStr.isEmpty()) {
         msg->references()->fromUnicodeString(QString::fromLocal8Bit(refStr), "utf-8");
     }
-    //In-Reply-To = original msg-id
+    // In-Reply-To = original msg-id
     msg->inReplyTo()->from7BitString(mOrigMsg->messageID()->as7BitString(false));
 
     msg->subject()->fromUnicodeString(MessageCore::StringUtil::replySubject(mOrigMsg.data()), "utf-8");
 
     // If the reply shouldn't be blank, apply the template to the message
     if (mQuote) {
-        MessageFactoryReplyJob *job = new MessageFactoryReplyJob;
+        auto job = new MessageFactoryReplyJob;
         connect(job, &MessageFactoryReplyJob::replyDone, this, &MessageFactoryNG::slotCreateReplyDone);
         job->setMsg(msg);
         job->setReplyAll(replyAll);
@@ -322,14 +309,14 @@ void MessageFactoryNG::createForwardAsync()
 
         msg->contentType(true)->setMimeType("multipart/mixed");
 
-        //TODO: Andras: somebody should check if this is correct. :)
+        // TODO: Andras: somebody should check if this is correct. :)
         // empty text part
-        KMime::Content *msgPart = new KMime::Content;
+        auto msgPart = new KMime::Content;
         msgPart->contentType()->setMimeType("text/plain");
         msg->addContent(msgPart);
 
         // the old contents of the mail
-        KMime::Content *secondPart = new KMime::Content;
+        auto secondPart = new KMime::Content;
         secondPart->contentType()->setMimeType(mOrigMsg->contentType()->mimeType());
         secondPart->setBody(mOrigMsg->body());
         // use the headers of the original mail
@@ -341,10 +328,10 @@ void MessageFactoryNG::createForwardAsync()
     // Just copy the message, the template parser will do the hard work of
     // replacing the body text in TemplateParser::addProcessedBodyToMessage()
     else {
-        //TODO Check if this is ok
+        // TODO Check if this is ok
         msg->setHead(mOrigMsg->head());
         msg->setBody(mOrigMsg->body());
-        const QString oldContentType = msg->contentType()->asUnicodeString();
+        const QString oldContentType = msg->contentType(true)->asUnicodeString();
         const uint originalIdentity = identityUoid(mOrigMsg);
         MessageHelper::initFromMessage(msg, mOrigMsg, mIdentityManager, originalIdentity);
 
@@ -355,7 +342,7 @@ void MessageFactoryNG::createForwardAsync()
     }
 
     msg->subject()->fromUnicodeString(MessageCore::StringUtil::forwardSubject(mOrigMsg.data()), "utf-8");
-    MessageFactoryForwardJob *job = new MessageFactoryForwardJob;
+    auto job = new MessageFactoryForwardJob;
     connect(job, &MessageFactoryForwardJob::forwardDone, this, &MessageFactoryNG::slotCreateForwardDone);
     job->setIdentityManager(mIdentityManager);
     job->setMsg(msg);
@@ -366,12 +353,12 @@ void MessageFactoryNG::createForwardAsync()
     job->start();
 }
 
-QPair< KMime::Message::Ptr, QVector< KMime::Content * > > MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
+QPair<KMime::Message::Ptr, QVector<KMime::Content *>> MessageFactoryNG::createAttachedForward(const Akonadi::Item::List &items)
 {
     // create forwarded message with original message as attachment
     // remove headers that shouldn't be forwarded
     KMime::Message::Ptr msg(new KMime::Message);
-    QVector< KMime::Content * > attachments;
+    QVector<KMime::Content *> attachments;
 
     const int numberOfItems(items.count());
     if (numberOfItems >= 2) {
@@ -386,16 +373,14 @@ QPair< KMime::Message::Ptr, QVector< KMime::Content * > > MessageFactoryNG::crea
     }
 
     MessageHelper::setAutomaticFields(msg, true);
-#ifndef QT_NO_CURSOR
-    KPIM::KCursorSaver busy(KPIM::KBusyPtr::busy());
-#endif
+    KCursorSaver saver(Qt::WaitCursor);
     if (numberOfItems == 0) {
         attachments << createForwardAttachmentMessage(mOrigMsg);
         MessageComposer::Util::addLinkInformation(msg, mId, Akonadi::MessageStatus::statusForwarded());
     } else {
         // iterate through all the messages to be forwarded
         attachments.reserve(items.count());
-        for (const Akonadi::Item &item : qAsConst(items)) {
+        for (const Akonadi::Item &item : std::as_const(items)) {
             attachments << createForwardAttachmentMessage(MessageComposer::Util::message(item));
             MessageComposer::Util::addLinkInformation(msg, item.id(), Akonadi::MessageStatus::statusForwarded());
         }
@@ -403,8 +388,8 @@ QPair< KMime::Message::Ptr, QVector< KMime::Content * > > MessageFactoryNG::crea
 
     applyCharset(msg);
 
-    //msg->assemble();
-    return QPair< KMime::Message::Ptr, QVector< KMime::Content * > >(msg, QVector< KMime::Content * >() << attachments);
+    // msg->assemble();
+    return QPair<KMime::Message::Ptr, QVector<KMime::Content *>>(msg, QVector<KMime::Content *>() << attachments);
 }
 
 KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Message::Ptr &fwdMsg)
@@ -414,14 +399,15 @@ KMime::Content *MessageFactoryNG::createForwardAttachmentMessage(const KMime::Me
     fwdMsg->removeHeader<KMime::Headers::Bcc>();
     fwdMsg->assemble();
     // set the part
-    KMime::Content *msgPart = new KMime::Content(fwdMsg.data());
-    msgPart->contentType()->setMimeType("message/rfc822");
+    auto msgPart = new KMime::Content(fwdMsg.data());
+    auto ct = msgPart->contentType();
+    ct->setMimeType("message/rfc822");
 
-    auto cd = msgPart->contentDisposition(); //create
+    auto cd = msgPart->contentDisposition(); // create
     cd->setParameter(QStringLiteral("filename"), i18n("forwarded message"));
     cd->setDisposition(KMime::Headers::CDinline);
     const QString subject = fwdMsg->subject()->asUnicodeString();
-    msgPart->contentType()->setParameter(QStringLiteral("name"), subject);
+    ct->setParameter(QStringLiteral("name"), subject);
     cd->fromUnicodeString(fwdMsg->from()->asUnicodeString() + QLatin1String(": ") + subject, "utf-8");
     msgPart->setBody(fwdMsg->encodedContent());
     msgPart->assemble();
@@ -449,7 +435,7 @@ KMime::Message::Ptr MessageFactoryNG::createResend()
     uint originalIdentity = identityUoid(mOrigMsg);
 
     // Set the identity from above
-    KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
+    auto header = new KMime::Headers::Generic("X-KMail-Identity");
     header->fromUnicodeString(QString::number(originalIdentity), "utf-8");
     msg->setHeader(header);
 
@@ -458,10 +444,11 @@ KMime::Message::Ptr MessageFactoryNG::createResend()
     return msg;
 }
 
-KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, const QString &bccStr, int transportId, const QString &fcc, int identity)
+KMime::Message::Ptr
+MessageFactoryNG::createRedirect(const QString &toStr, const QString &ccStr, const QString &bccStr, int transportId, const QString &fcc, int identity)
 {
     if (!mOrigMsg) {
-        return KMime::Message::Ptr();
+        return {};
     }
 
     // copy the message 1:1
@@ -478,24 +465,21 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
             }
         }
     }
-    const KIdentityManagement::Identity &ident
-        = mIdentityManager->identityForUoidOrDefault(id);
+    const KIdentityManagement::Identity &ident = mIdentityManager->identityForUoidOrDefault(id);
 
     // X-KMail-Redirect-From: content
-    const QString strByWayOf = QString::fromLocal8Bit("%1 (by way of %2 <%3>)")
-                               .arg(mOrigMsg->from()->asUnicodeString(), ident.fullName(), ident.primaryEmailAddress());
+    const QString strByWayOf =
+        QString::fromLocal8Bit("%1 (by way of %2 <%3>)").arg(mOrigMsg->from()->asUnicodeString(), ident.fullName(), ident.primaryEmailAddress());
 
     // Resent-From: content
-    const QString strFrom = QString::fromLocal8Bit("%1 <%2>")
-                            .arg(ident.fullName(), ident.primaryEmailAddress());
+    const QString strFrom = QString::fromLocal8Bit("%1 <%2>").arg(ident.fullName(), ident.primaryEmailAddress());
 
     // format the current date to be used in Resent-Date:
     // FIXME: generate datetime the same way as KMime, otherwise we get inconsistency
-    // in unit-tests. Unfortunatelly RFC2822Date is not enough for us, we need the
+    // in unit-tests. Unfortunately RFC2822Date is not enough for us, we need the
     // composition hack below
     const QDateTime dt = QDateTime::currentDateTime();
-    const QString newDate = QLocale::c().toString(dt, QStringLiteral("ddd, "))
-                            +dt.toString(Qt::RFC2822Date);
+    const QString newDate = QLocale::c().toString(dt, QStringLiteral("ddd, ")) + dt.toString(Qt::RFC2822Date);
 
     // Clean up any resent headers
     msg->removeHeader("Resent-Cc");
@@ -508,7 +492,7 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
     if (MessageComposer::MessageComposerSettings::useCustomMessageIdSuffix()) {
         msgIdSuffix = MessageComposer::MessageComposerSettings::customMsgIDSuffix();
     }
-    KMime::Headers::Generic *header = new KMime::Headers::Generic("Resent-Message-ID");
+    auto header = new KMime::Headers::Generic("Resent-Message-ID");
     header->fromUnicodeString(MessageCore::StringUtil::generateMessageId(msg->sender()->asUnicodeString(), msgIdSuffix), "utf-8");
     msg->setHeader(header);
 
@@ -521,7 +505,7 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
     msg->setHeader(header);
 
     if (msg->to(false)) {
-        KMime::Headers::To *headerT = new KMime::Headers::To;
+        auto headerT = new KMime::Headers::To;
         headerT->fromUnicodeString(mOrigMsg->to()->asUnicodeString(), "utf-8");
         msg->setHeader(headerT);
     }
@@ -560,7 +544,7 @@ KMime::Message::Ptr MessageFactoryNG::createRedirect(const QString &toStr, const
 
     const bool fccIsDisabled = ident.disabledFcc();
     if (fccIsDisabled) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-FccDisabled");
+        header = new KMime::Headers::Generic("X-KMail-FccDisabled");
         header->fromUnicodeString(QStringLiteral("true"), "utf-8");
         msg->setHeader(header);
     } else {
@@ -580,7 +564,7 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
         receiptTo = hrd->asUnicodeString();
     }
     if (receiptTo.trimmed().isEmpty()) {
-        return KMime::Message::Ptr();
+        return {};
     }
     receiptTo.remove(QChar::fromLatin1('\n'));
 
@@ -603,7 +587,11 @@ KMime::Message::Ptr MessageFactoryNG::createDeliveryReceipt()
     return receipt;
 }
 
-KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime::MDN::DispositionType d, KMime::MDN::SendingMode s, int mdnQuoteOriginal, const QVector<KMime::MDN::DispositionModifier> &m)
+KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a,
+                                                KMime::MDN::DispositionType d,
+                                                KMime::MDN::SendingMode s,
+                                                int mdnQuoteOriginal,
+                                                const QVector<KMime::MDN::DispositionModifier> &m)
 {
     // extract where to send to:
     QString receiptTo;
@@ -627,7 +615,7 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     KMime::Message::Ptr receipt(new KMime::Message());
     const uint originalIdentity = identityUoid(mOrigMsg);
     MessageHelper::initFromMessage(receipt, mOrigMsg, mIdentityManager, originalIdentity);
-    auto contentType = receipt->contentType(true); //create it
+    auto contentType = receipt->contentType(true); // create it
     contentType->from7BitString("multipart/report");
     contentType->setBoundary(KMime::multiPartBoundary());
     contentType->setCharset("us-ascii");
@@ -638,8 +626,8 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     const QString description = replaceHeadersInString(mOrigMsg, KMime::MDN::descriptionFor(d, m));
 
     // text/plain part:
-    KMime::Content *firstMsgPart = new KMime::Content(mOrigMsg.data());
-    auto firstMsgPartContentType = firstMsgPart->contentType(); //create it
+    auto firstMsgPart = new KMime::Content(mOrigMsg.data());
+    auto firstMsgPartContentType = firstMsgPart->contentType(); // create it
     firstMsgPartContentType->setMimeType("text/plain");
     firstMsgPartContentType->setCharset("utf-8");
     firstMsgPart->contentTransferEncoding(true)->setEncoding(KMime::Headers::CE7Bit);
@@ -647,7 +635,7 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     receipt->addContent(firstMsgPart);
 
     // message/disposition-notification part:
-    KMime::Content *secondMsgPart = new KMime::Content(mOrigMsg.data());
+    auto secondMsgPart = new KMime::Content(mOrigMsg.data());
     secondMsgPart->contentType()->setMimeType("message/disposition-notification");
 
     secondMsgPart->contentTransferEncoding()->setEncoding(KMime::Headers::CE7Bit);
@@ -655,11 +643,14 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     if (auto hrd = mOrigMsg->headerByType("Original-Recipient")) {
         originalRecipient = hrd->as7BitString(false);
     }
-    secondMsgPart->setBody(KMime::MDN::dispositionNotificationBodyContent(
-                               finalRecipient,
-                               originalRecipient,
-                               mOrigMsg->messageID()->as7BitString(false), /* Message-ID */
-                               d, a, s, m, special));
+    secondMsgPart->setBody(KMime::MDN::dispositionNotificationBodyContent(finalRecipient,
+                                                                          originalRecipient,
+                                                                          mOrigMsg->messageID()->as7BitString(false), /* Message-ID */
+                                                                          d,
+                                                                          a,
+                                                                          s,
+                                                                          m,
+                                                                          special));
     receipt->addContent(secondMsgPart);
 
     if ((mdnQuoteOriginal < 0) || (mdnQuoteOriginal > 2)) {
@@ -667,7 +658,7 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     }
     /* 0=> Nothing, 1=>Full Message, 2=>HeadersOnly*/
 
-    KMime::Content *thirdMsgPart = new KMime::Content(mOrigMsg.data());
+    auto thirdMsgPart = new KMime::Content(mOrigMsg.data());
     switch (mdnQuoteOriginal) {
     case 1:
         thirdMsgPart->contentType()->setMimeType("message/rfc822");
@@ -686,9 +677,9 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     }
 
     receipt->to()->fromUnicodeString(receiptTo, "utf-8");
-    //Laurent: We don't translate subject ?
+    // Laurent: We don't translate subject ?
     receipt->subject()->from7BitString("Message Disposition Notification");
-    KMime::Headers::InReplyTo *header = new KMime::Headers::InReplyTo;
+    auto header = new KMime::Headers::InReplyTo;
     header->fromUnicodeString(mOrigMsg->messageID()->asUnicodeString(), "utf-8");
     receipt->setHeader(header);
 
@@ -702,22 +693,24 @@ KMime::Message::Ptr MessageFactoryNG::createMDN(KMime::MDN::ActionMode a, KMime:
     return receipt;
 }
 
-QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDigestMIME(const Akonadi::Item::List &items)
+QPair<KMime::Message::Ptr, KMime::Content *> MessageFactoryNG::createForwardDigestMIME(const Akonadi::Item::List &items)
 {
     KMime::Message::Ptr msg(new KMime::Message);
-    KMime::Content *digest = new KMime::Content(msg.data());
+    auto digest = new KMime::Content(msg.data());
 
-    const QString mainPartText = i18n("\nThis is a MIME digest forward. The content of the"
-                                " message is contained in the attachment(s).\n\n\n");
+    const QString mainPartText = i18n(
+        "\nThis is a MIME digest forward. The content of the"
+        " message is contained in the attachment(s).\n\n\n");
 
-    digest->contentType()->setMimeType("multipart/digest");
-    digest->contentType()->setBoundary(KMime::multiPartBoundary());
+    auto ct = digest->contentType();
+    ct->setMimeType("multipart/digest");
+    ct->setBoundary(KMime::multiPartBoundary());
     digest->contentDescription()->fromUnicodeString(QStringLiteral("Digest of %1 messages.").arg(items.count()), "utf8");
     digest->contentDisposition()->setFilename(QStringLiteral("digest"));
     digest->fromUnicodeString(mainPartText);
 
     int id = 0;
-    for (const Akonadi::Item &item : qAsConst(items)) {
+    for (const Akonadi::Item &item : std::as_const(items)) {
         KMime::Message::Ptr fMsg = MessageComposer::Util::message(item);
         if (id == 0) {
             if (auto hrd = fMsg->headerByType("X-KMail-Identity")) {
@@ -728,10 +721,10 @@ QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDi
         MessageCore::StringUtil::removePrivateHeaderFields(fMsg);
         fMsg->removeHeader<KMime::Headers::Bcc>();
         fMsg->assemble();
-        KMime::Content *part = new KMime::Content(digest);
+        auto part = new KMime::Content(digest);
 
         part->contentType()->setMimeType("message/rfc822");
-        part->contentType()->setCharset(fMsg->contentType()->charset());
+        part->contentType(false)->setCharset(fMsg->contentType()->charset());
         part->contentID()->setIdentifier(fMsg->contentID()->identifier());
         part->contentDescription()->fromUnicodeString(fMsg->contentDescription()->asUnicodeString(), "utf8");
         part->contentDisposition()->setParameter(QStringLiteral("name"), i18n("forwarded message"));
@@ -747,7 +740,7 @@ QPair< KMime::Message::Ptr, KMime::Content * > MessageFactoryNG::createForwardDi
 
     //   qCDebug(MESSAGECOMPOSER_LOG) << "digest:" << digest->contents().size() << digest->encodedContent();
 
-    return QPair< KMime::Message::Ptr, KMime::Content * >(msg, digest);
+    return QPair<KMime::Message::Ptr, KMime::Content *>(msg, digest);
 }
 
 void MessageFactoryNG::setIdentityManager(KIdentityManagement::IdentityManager *ident)
@@ -780,7 +773,7 @@ void MessageFactoryNG::setMailingListAddresses(const KMime::Types::Mailbox::List
     mMailingListAddresses << listAddresses;
 }
 
-void MessageFactoryNG::setFolderIdentity(Akonadi::Collection::Id folderIdentityId)
+void MessageFactoryNG::setFolderIdentity(uint folderIdentityId)
 {
     mFolderId = folderIdentityId;
 }
@@ -819,8 +812,7 @@ bool MessageFactoryNG::MDNConfirmMultipleRecipients(const KMime::Message::Ptr &m
     // RFC 2298: [ Confirmation from the user SHOULD be obtained (or no
     // MDN sent) ] if there is more than one distinct address in the
     // Disposition-Notification-To header.
-    qCDebug(MESSAGECOMPOSER_LOG) << "KEmailAddress::splitAddressList(receiptTo):"
-                                 << KEmailAddress::splitAddressList(receiptTo).join(QLatin1Char('\n'));
+    qCDebug(MESSAGECOMPOSER_LOG) << "KEmailAddress::splitAddressList(receiptTo):" << KEmailAddress::splitAddressList(receiptTo).join(QLatin1Char('\n'));
 
     return KEmailAddress::splitAddressList(receiptTo).count() > 1;
 }
@@ -843,8 +835,7 @@ bool MessageFactoryNG::MDNReturnPathEmpty(const KMime::Message::Ptr &msg)
     // SHOULD be obtained (or no MDN sent) if there is no Return-Path
     // header in the message [...]
     KMime::Types::AddrSpecList returnPathList = MessageHelper::extractAddrSpecs(msg, "Return-Path");
-    QString returnPath = returnPathList.isEmpty() ? QString()
-                         : returnPathList.front().localPart + QChar::fromLatin1('@') + returnPathList.front().domain;
+    const QString returnPath = returnPathList.isEmpty() ? QString() : returnPathList.front().localPart + QChar::fromLatin1('@') + returnPathList.front().domain;
     qCDebug(MESSAGECOMPOSER_LOG) << "clean return path:" << returnPath;
     return returnPath.isEmpty();
 }
@@ -867,8 +858,7 @@ bool MessageFactoryNG::MDNReturnPathNotInRecieptTo(const KMime::Message::Ptr &ms
     // SHOULD be obtained (or no MDN sent) if there is no Return-Path
     // header in the message [...]
     KMime::Types::AddrSpecList returnPathList = MessageHelper::extractAddrSpecs(msg, QStringLiteral("Return-Path").toLatin1());
-    QString returnPath = returnPathList.isEmpty() ? QString()
-                         : returnPathList.front().localPart + QChar::fromLatin1('@') + returnPathList.front().domain;
+    const QString returnPath = returnPathList.isEmpty() ? QString() : returnPathList.front().localPart + QChar::fromLatin1('@') + returnPathList.front().domain;
     qCDebug(MESSAGECOMPOSER_LOG) << "clean return path:" << returnPath;
     return !receiptTo.contains(returnPath, Qt::CaseSensitive);
 }
@@ -904,11 +894,7 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
     uint id = idString.toUInt(&ok);
 
     if (!ok || id == 0) {
-        id = mIdentityManager->identityForAddress(msg->to()->asUnicodeString() + QLatin1String(", ") + msg->cc()->asUnicodeString()).uoid();
-    }
-
-    if (id == 0 && mFolderId > 0) {
-        id = mFolderId;
+        id = MessageCore::Util::identityForMessage(msg.data(), mIdentityManager, mFolderId).uoid();
     }
     return id;
 }
@@ -916,27 +902,23 @@ uint MessageFactoryNG::identityUoid(const KMime::Message::Ptr &msg)
 QString MessageFactoryNG::replaceHeadersInString(const KMime::Message::Ptr &msg, const QString &s)
 {
     QString result = s;
-    static QRegularExpression rx {
-        QStringLiteral("\\$\\{([a-z0-9-]+)\\}"),
-        QRegularExpression::CaseInsensitiveOption
-    };
+    static QRegularExpression rx{QStringLiteral("\\$\\{([a-z0-9-]+)\\}"), QRegularExpression::CaseInsensitiveOption};
 
-    const QString sDate = KMime::DateFormatter::formatDate(
-        KMime::DateFormatter::Localized, msg->date()->dateTime().toSecsSinceEpoch());
+    const QString sDate = KMime::DateFormatter::formatDate(KMime::DateFormatter::Localized, msg->date()->dateTime().toSecsSinceEpoch());
     qCDebug(MESSAGECOMPOSER_LOG) << "creating mdn date:" << msg->date()->dateTime().toSecsSinceEpoch() << sDate;
 
     result.replace(QStringLiteral("${date}"), sDate);
 
     int idx = 0;
     for (auto match = rx.match(result); match.hasMatch(); match = rx.match(result, idx)) {
-        idx = match.capturedStart(1);
+        idx = match.capturedStart(0);
         const QByteArray ba = match.captured(1).toLatin1();
         if (auto hdr = msg->headerByType(ba.constData())) {
             const auto replacement = hdr->asUnicodeString();
-            result.replace(idx, match.capturedLength(1), replacement);
+            result.replace(idx, match.capturedLength(0), replacement);
             idx += replacement.length();
         } else {
-            result.remove(idx, match.capturedLength(1));
+            result.remove(idx, match.capturedLength(0));
         }
     }
     return result;
@@ -959,7 +941,7 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
         QTextCodec *codec = KCharsets::charsets()->codecForName(QString::fromLatin1(msg->contentType()->charset()));
         if (!codec) {
             qCCritical(MESSAGECOMPOSER_LOG) << "Could not get text codec for charset" << msg->contentType()->charset();
-        } else if (!codec->canEncode(body)) {     // charset can't encode body, fall back to preferred
+        } else if (!codec->canEncode(body)) { // charset can't encode body, fall back to preferred
             const QStringList charsets = MessageComposer::MessageComposerSettings::preferredCharsets();
 
             QVector<QByteArray> chars;
@@ -983,8 +965,12 @@ void MessageFactoryNG::applyCharset(const KMime::Message::Ptr msg)
 
 QByteArray MessageFactoryNG::getRefStr(const KMime::Message::Ptr &msg)
 {
-    QByteArray firstRef, lastRef, refStr, retRefStr;
-    int i, j;
+    QByteArray firstRef;
+    QByteArray lastRef;
+    QByteArray refStr;
+    QByteArray retRefStr;
+    int i;
+    int j;
 
     if (auto hdr = msg->references(false)) {
         refStr = hdr->as7BitString(false).trimmed();
