@@ -9,44 +9,49 @@
 #include "recipientspicker.h"
 #include "settings/messagecomposersettings.h"
 
-#include <Akonadi/Contact/EmailAddressSelectionWidget>
-#include <Akonadi/Contact/RecipientsPickerWidget>
-#include <kcontacts/contactgroup.h>
+#include <Akonadi/EmailAddressSelectionWidget>
+#include <Akonadi/RecipientsPickerWidget>
+#include <KContacts/ContactGroup>
 #include <PimCommonAkonadi/LdapSearchDialog>
 
+#include "messagecomposer_debug.h"
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QLineEdit>
 #include <QPushButton>
-#include "messagecomposer_debug.h"
 
-#include <QKeyEvent>
-#include <QTreeView>
-#include <QVBoxLayout>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
+#include <QKeyEvent>
+#include <QLabel>
+#include <QTreeView>
+#include <QVBoxLayout>
 
 using namespace MessageComposer;
-
+namespace
+{
+static const char myRecipientsPickerConfigGroupName[] = "RecipientsPicker";
+}
 RecipientsPicker::RecipientsPicker(QWidget *parent)
     : QDialog(parent)
+    , mView(new Akonadi::RecipientsPickerWidget(true, nullptr, this))
+    , mSelectedLabel(new QLabel(this))
 {
     setObjectName(QStringLiteral("RecipientsPicker"));
     setWindowTitle(i18nc("@title:window", "Select Recipient"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    mView = new Akonadi::RecipientsPickerWidget(false, nullptr, this);
     mainLayout->addWidget(mView);
     mainLayout->setStretchFactor(mView, 1);
 
-    connect(mView->view()->selectionModel(), &QItemSelectionModel::selectionChanged,
-            this, &RecipientsPicker::slotSelectionChanged);
-    connect(mView->view(), &QAbstractItemView::doubleClicked,
-            this, &RecipientsPicker::slotPicked);
+    connect(mView->view()->selectionModel(), &QItemSelectionModel::selectionChanged, this, &RecipientsPicker::slotSelectionChanged);
+    connect(mView->view(), &QAbstractItemView::doubleClicked, this, &RecipientsPicker::slotPicked);
 
-    QPushButton *searchLDAPButton = new QPushButton(i18n("Search &Directory Service"), this);
+    mainLayout->addWidget(mSelectedLabel);
+
+    auto searchLDAPButton = new QPushButton(i18n("Search &Directory Service"), this);
     connect(searchLDAPButton, &QPushButton::clicked, this, &RecipientsPicker::slotSearchLDAP);
     mainLayout->addWidget(searchLDAPButton);
 
@@ -57,14 +62,14 @@ RecipientsPicker::RecipientsPicker(QWidget *parent)
         searchLDAPButton->setVisible(false);
     }
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    mUser1Button = new QPushButton;
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
+    mUser1Button = new QPushButton(this);
     buttonBox->addButton(mUser1Button, QDialogButtonBox::ActionRole);
-    mUser2Button = new QPushButton;
+    mUser2Button = new QPushButton(this);
     buttonBox->addButton(mUser2Button, QDialogButtonBox::ActionRole);
-    mUser3Button = new QPushButton;
+    mUser3Button = new QPushButton(this);
     buttonBox->addButton(mUser3Button, QDialogButtonBox::ActionRole);
-    mUser4Button = new QPushButton;
+    mUser4Button = new QPushButton(this);
     buttonBox->addButton(mUser4Button, QDialogButtonBox::ActionRole);
 
     connect(buttonBox, &QDialogButtonBox::rejected, this, &RecipientsPicker::reject);
@@ -90,13 +95,24 @@ RecipientsPicker::~RecipientsPicker()
     writeConfig();
 }
 
+void RecipientsPicker::updateLabel(int nbSelected)
+{
+    if (nbSelected == 0) {
+        mSelectedLabel->setText({});
+    } else {
+        mSelectedLabel->setText(i18np("%1 selected email", "%1 selected emails", nbSelected));
+    }
+}
+
 void RecipientsPicker::slotSelectionChanged()
 {
-    const bool hasSelection = !mView->emailAddressSelectionWidget()->selectedAddresses().isEmpty();
+    const auto selectedItems{mView->emailAddressSelectionWidget()->selectedAddresses().count()};
+    const bool hasSelection = (selectedItems != 0);
     mUser1Button->setEnabled(hasSelection);
     mUser2Button->setEnabled(hasSelection);
     mUser3Button->setEnabled(hasSelection);
     mUser4Button->setEnabled(hasSelection);
+    updateLabel(selectedItems);
 }
 
 void RecipientsPicker::setRecipients(const Recipient::List &)
@@ -107,9 +123,9 @@ void RecipientsPicker::setRecipients(const Recipient::List &)
 void RecipientsPicker::setDefaultType(Recipient::Type type)
 {
     mDefaultType = type;
-    mUser1Button->setDefault(type == Recipient::To);
+    mUser1Button->setDefault(type == Recipient::Bcc);
     mUser2Button->setDefault(type == Recipient::Cc);
-    mUser3Button->setDefault(type == Recipient::Bcc);
+    mUser3Button->setDefault(type == Recipient::To);
     mUser4Button->setDefault(type == Recipient::ReplyTo);
 }
 
@@ -152,9 +168,10 @@ void RecipientsPicker::pick(Recipient::Type type)
     if (count > MessageComposerSettings::self()->maximumRecipients()) {
         KMessageBox::sorry(this,
                            i18np("You selected 1 recipient. The maximum supported number of "
-                                 "recipients is %2. Please adapt the selection.",
+                                 "recipients is %2.\nPlease adapt the selection.",
                                  "You selected %1 recipients. The maximum supported number of "
-                                 "recipients is %2. Please adapt the selection.", count,
+                                 "recipients is %2.\nPlease adapt the selection.",
+                                 count,
                                  MessageComposerSettings::self()->maximumRecipients()));
         return;
     }
@@ -167,6 +184,7 @@ void RecipientsPicker::pick(Recipient::Type type)
 
         Q_EMIT pickedRecipient(recipient, tooManyAddress);
         if (tooManyAddress) {
+            KMessageBox::sorry(this, i18n("You can not add more recipients."));
             break;
         }
     }
@@ -183,9 +201,9 @@ void RecipientsPicker::keyPressEvent(QKeyEvent *event)
 
 void RecipientsPicker::readConfig()
 {
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "RecipientsPicker");
-    QSize size = group.readEntry("Size", QSize());
+    KSharedConfig::Ptr cfg = KSharedConfig::openStateConfig();
+    const KConfigGroup group(cfg, myRecipientsPickerConfigGroupName);
+    const QSize size = group.readEntry("Size", QSize());
     if (!size.isEmpty()) {
         resize(size);
     }
@@ -193,8 +211,8 @@ void RecipientsPicker::readConfig()
 
 void RecipientsPicker::writeConfig()
 {
-    KSharedConfig::Ptr cfg = KSharedConfig::openConfig();
-    KConfigGroup group(cfg, "RecipientsPicker");
+    KSharedConfig::Ptr cfg = KSharedConfig::openStateConfig();
+    KConfigGroup group(cfg, myRecipientsPickerConfigGroupName);
     group.writeEntry("Size", size());
 }
 
