@@ -22,13 +22,13 @@
 #include <MimeTreeParser/NodeHelper>
 #include <MimeTreeParser/PartNodeBodyPart>
 
-#include <Akonadi/Contact/OpenEmailAddressJob>
+#include <Akonadi/OpenEmailAddressJob>
 #include <MessageCore/StringUtil>
 #include <PimCommon/BroadcastStatus>
 
-#include <Akonadi/Contact/ContactSearchJob>
+#include <Akonadi/ContactSearchJob>
 
-#include "messageflags.h"
+#include <Akonadi/MessageFlags>
 #include <KEmailAddress>
 #include <KMbox/MBox>
 #include <KMime/Content>
@@ -57,7 +57,6 @@
 
 using namespace std::chrono_literals;
 
-using std::find;
 using std::for_each;
 using std::remove;
 using namespace MessageViewer;
@@ -197,7 +196,7 @@ QString BodyPartURLHandlerManager::statusBarMessage(const QUrl &url, ViewerPriva
     QString path;
     KMime::Content *node = partNodeFromXKMailUrl(url, w, &path);
     if (!node) {
-        return QString();
+        return {};
     }
 
     MimeTreeParser::PartNodeBodyPart part(nullptr, nullptr, w->message().data(), node, w->nodeHelper());
@@ -210,7 +209,7 @@ QString BodyPartURLHandlerManager::statusBarMessage(const QUrl &url, ViewerPriva
             }
         }
     }
-    return QString();
+    return {};
 }
 
 //
@@ -342,7 +341,7 @@ QString URLHandlerManager::statusBarMessage(const QUrl &url, ViewerPrivate *w) c
             return msg;
         }
     }
-    return QString();
+    return {};
 }
 
 //
@@ -421,12 +420,12 @@ QString KMailProtocolURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate
         } else if (urlPath == QLatin1String("hideEncryptionDetails")) {
             return i18n("Hide encryption details.");
         } else {
-            return QString();
+            return {};
         }
     } else if (schemeStr == QLatin1String("help")) {
         return i18n("Open Documentation");
     }
-    return QString();
+    return {};
 }
 
 bool ExpandCollapseQuoteURLManager::handleClick(const QUrl &url, ViewerPrivate *w) const
@@ -464,7 +463,7 @@ QString ExpandCollapseQuoteURLManager::statusBarMessage(const QUrl &url, ViewerP
             }
         }
     }
-    return QString();
+    return {};
 }
 
 bool foundSMIMEData(const QString &aUrl, QString &displayName, QString &libName, QString &keyId)
@@ -518,12 +517,16 @@ bool SMimeURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
     QStringList lst;
     lst << QStringLiteral("--parent-windowid") << QString::number(static_cast<qlonglong>(w->viewer()->mainWindow()->winId())) << QStringLiteral("--query")
         << keyId;
-    if (!QProcess::startDetached(QStringLiteral("kleopatra"), lst)) {
+    const QString exec = QStandardPaths::findExecutable(QStringLiteral("kleopatra"));
+    if (exec.isEmpty()) {
+        qCWarning(MESSAGEVIEWER_LOG) << "Could not find kleopatra executable in PATH";
         KMessageBox::error(w->mMainWindow,
                            i18n("Could not start certificate manager. "
                                 "Please check your installation."),
                            i18n("KMail Error"));
+        return false;
     }
+    QProcess::startDetached(exec, lst);
     return true;
 }
 
@@ -533,7 +536,7 @@ QString SMimeURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) cons
     QString libName;
     QString keyId;
     if (!foundSMIMEData(url.path() + QLatin1Char('#') + QUrl::fromPercentEncoding(url.fragment().toLatin1()), displayName, libName, keyId)) {
-        return QString();
+        return {};
     }
     return i18n("Show certificate 0x%1", keyId);
 }
@@ -553,7 +556,7 @@ QString MailToURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) con
     if (url.scheme() == QLatin1String("mailto")) {
         return KEmailAddress::decodeMailtoUrl(url);
     }
-    return QString();
+    return {};
 }
 
 static QString searchFullEmailByUid(const QString &uid)
@@ -622,7 +625,7 @@ QString ContactUidURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *)
     if (url.scheme() == QLatin1String("uid")) {
         return i18n("Lookup the contact in KAddressbook");
     } else {
-        return QString();
+        return {};
     }
 }
 
@@ -774,7 +777,7 @@ bool AttachmentURLHandler::handleDrag(const QUrl &url, ViewerPrivate *window) co
     } else {
 #endif
         return false;
-}
+    }
 }
 
 bool AttachmentURLHandler::handleContextMenuRequest(const QUrl &url, const QPoint &p, ViewerPrivate *w) const
@@ -792,7 +795,7 @@ QString AttachmentURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *w
 {
     KMime::Content *node = nodeForUrl(url, w);
     if (!node) {
-        return QString();
+        return {};
     }
     const QString name = MimeTreeParser::NodeHelper::fileName(node);
     if (!name.isEmpty()) {
@@ -810,7 +813,7 @@ QString AttachmentURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *w
 static QString extractAuditLog(const QUrl &url)
 {
     if (url.scheme() != QLatin1String("kmail") || url.path() != QLatin1String("showAuditLog")) {
-        return QString();
+        return {};
     }
     QUrlQuery query(url);
     Q_ASSERT(!query.queryItemValue(QStringLiteral("log")).isEmpty());
@@ -837,7 +840,7 @@ bool ShowAuditLogURLHandler::handleContextMenuRequest(const QUrl &url, const QPo
 QString ShowAuditLogURLHandler::statusBarMessage(const QUrl &url, ViewerPrivate *) const
 {
     if (extractAuditLog(url).isEmpty()) {
-        return QString();
+        return {};
     } else {
         return i18n("Show GnuPG Audit Log for this operation");
     }
@@ -877,7 +880,8 @@ bool KRunURLHandler::handleClick(const QUrl &url, ViewerPrivate *w) const
     const QString scheme(url.scheme());
     if ((scheme == QLatin1String("http")) || (scheme == QLatin1String("https")) || (scheme == QLatin1String("ftp")) || (scheme == QLatin1String("file"))
         || (scheme == QLatin1String("ftps")) || (scheme == QLatin1String("sftp")) || (scheme == QLatin1String("help")) || (scheme == QLatin1String("vnc"))
-        || (scheme == QLatin1String("smb")) || (scheme == QLatin1String("fish")) || (scheme == QLatin1String("news")) || (scheme == QLatin1String("tel"))) {
+        || (scheme == QLatin1String("smb")) || (scheme == QLatin1String("fish")) || (scheme == QLatin1String("news")) || (scheme == QLatin1String("tel"))
+        || (scheme == QLatin1String("geo"))) {
         PimCommon::BroadcastStatus::instance()->setTransientStatusMsg(i18n("Opening URL..."));
         QTimer::singleShot(2s, PimCommon::BroadcastStatus::instance(), &PimCommon::BroadcastStatus::reset);
 
