@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ CidSchemeHandler::CidSchemeHandler(QObject *parent)
 {
 }
 
-CidSchemeHandler::~CidSchemeHandler()
-{
-}
+CidSchemeHandler::~CidSchemeHandler() = default;
 
 void CidSchemeHandler::requestStarted(QWebEngineUrlRequestJob *job)
 {
